import { fetchBookChapterLinks } from "@/lib/api";
import { Book } from "@/lib/types";
import { formatDateToMonthDayYear } from "@/lib/utils";
import ChapterDropdown from "@/components/ChapterDropdown";

export type paramsType = Promise<{ bookId: string}>;


export default async function BookPage(props: { params: paramsType }) {
    const { bookId } = await props.params;

    let book: Book;
    try {
        book = await fetchBookChapterLinks(bookId);
    } catch (error) {
        console.error(error);
        return (
            <div className="text-center mt-10 text-red-500">
                Error fetching book data. Please try again later.
            </div>
        );
    }

    const { Name, Author, Description, chapters } = book;
    const recentChapters = chapters.length > 6 ? chapters.slice(chapters.length - 6, chapters.length) : chapters;
    return (
            <div className="max-w-6xl mx-auto py-10 px-4">
                <div className="flex items-center justify-between mb-4 pt-4">
                    {/* Book Title */}
                    <h1 className="text-5xl font-bold">{Name}</h1>

                    {/* Patreon Button */}
                    <a
                        href="https://www.patreon.com/c/nulltranslationgroup/membership?view_as=patron" // Replace with your Patreon URL
                        target="_blank"
                        rel="noopener noreferrer"
                        className="ml-4 bg-yellow-500 text-white font-semibold py-2 px-4 rounded hover:bg-yellow-600 transition duration-200"
                    >
                        Join Our Patreon for Unreleased Chapters
                    </a>
                </div>

                <p className="text-lg text-gray-600 dark:text-gray-400 mb-4">
                    <strong>Author:</strong> {Author}
                    <br></br>
                    <strong>Translator:</strong> Null Translation Group
                </p>
                <p className="mb-6">{Description}</p>

                <h2 className="text-3xl font-semibold mb-4">Recent Chapters</h2>
                <ul className="grid gap-6 sm:grid-cols-1 md:grid-cols-2 lg:grid-cols-3">
                    {recentChapters.map((chapter) => (
                        <li key={chapter.id}>
                            <a
                                href={`/books/${bookId}/chapters/${chapter.documentId}`}
                                className="block bg-white dark:bg-gray-800 rounded-lg shadow p-4 hover:shadow-lg transition duration-200"
                            >
                                <h3 className="text-xl font-medium">
                                    Chapter {chapter.Chapter_Number}: {chapter.Name}
                                </h3>
                                <p className="text-sm text-gray-500 dark:text-gray-400 mt-2">
                                    <strong>Release Date:</strong> {formatDateToMonthDayYear(new Date(chapter.ReleaseDate))}
                                </p>
                            </a>
                        </li>
                    ))}
                </ul>
                <div className="flex items-center justify-between mb-4 pt-4">
                    <h2 className="text-3xl font-semibold">All Chapters</h2>
                    <ChapterDropdown chapters={chapters} bookId={bookId} />
                </div>
                {chapters.map((chapter) => (
                    <li key={chapter.id} className="mb-2 list-none">
                        <a
                            href={`/books/${bookId}/chapters/${chapter.documentId}`}
                            className="block bg-white dark:bg-gray-800 rounded-lg shadow p-4 hover:shadow-lg transition duration-200"
                        >
                            <h3 className="text-xl font-medium">
                                Chapter {chapter.Chapter_Number}: {chapter.Name}
                            </h3>
                            <p className="text-sm text-gray-500 dark:text-gray-400 mt-2">
                                <strong>Release Date:</strong> {formatDateToMonthDayYear(new Date(chapter.ReleaseDate))}
                            </p>
                        </a>
                    </li>
                ))}
            </div>);
}
